---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: true
description: "You can use the hosted version of the Open Web Calendar yourself."
---

# Hosted Version

A hosted version exists at [open-web-calendar.hosted.quelltext.eu]({{link.web}}).
You can use this version if you like.
It is deployed from the latest version on the `master` branch.
Thus, translation improvements go there after max. 48 hours.
This version is intended to stay free of charge and is funded by [donation ♥️](../../contributing).

There is a version from which you can access calendars which are hosted
in [Tor Onion Services](https://tb-manual.torproject.org/onion-services/):
[tor.open-web-calendar.hosted.quelltext.eu]({{link.tor}}).

If you decide later to [setup your own server](../self), you can do this and [migrate all
calendars](../migrate) you use to the other server.

See also:

- [How to configure all calendar parameters](../configure/#configuring-the-default-calendar)
